@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2023 Joël Krähemann
+ * Copyright (C) 2005-2024 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -46,6 +46,7 @@ xmlNode* ags_composite_edit_list_resource(AgsConnectable *connectable);
 xmlNode* ags_composite_edit_xml_compose(AgsConnectable *connectable);
 void ags_composite_edit_xml_parse(AgsConnectable *connectable,
 				  xmlNode *node);
+
 gboolean ags_composite_edit_is_connected(AgsConnectable *connectable);
 void ags_composite_edit_connect(AgsConnectable *connectable);
 void ags_composite_edit_disconnect(AgsConnectable *connectable);
@@ -461,8 +462,6 @@ ags_composite_edit_connect(AgsConnectable *connectable)
 {
   AgsCompositeEdit *composite_edit;
 
-  GtkAdjustment *composite_adjustment;
-
   composite_edit = AGS_COMPOSITE_EDIT(connectable);
 
   if(ags_connectable_is_connected(connectable)){
@@ -502,19 +501,26 @@ ags_composite_edit_connect(AgsConnectable *connectable)
   }
   
   if(AGS_IS_NOTATION_EDIT(composite_edit->edit)){
-    composite_adjustment = gtk_scrollbar_get_adjustment(AGS_NOTATION_EDIT(composite_edit->edit)->vscrollbar);
+    GtkAdjustment *vadjustment, *hadjustment;
+    GtkAdjustment *composite_adjustment;
 
-    g_signal_connect_after(composite_adjustment, "value-changed",
+    vadjustment = gtk_scrollbar_get_adjustment(composite_edit->vscrollbar);
+
+    g_signal_connect_after(vadjustment, "value-changed",
 			   G_CALLBACK(ags_composite_edit_vscrollbar_callback), composite_edit);
     
+    composite_adjustment = gtk_scrollbar_get_adjustment(AGS_NOTATION_EDIT(composite_edit->edit)->vscrollbar);
+
     g_signal_connect_after(composite_adjustment, "changed",
 			   G_CALLBACK(ags_composite_edit_vscrollbar_changed), composite_edit);
 
-    composite_adjustment = gtk_scrollbar_get_adjustment(AGS_NOTATION_EDIT(composite_edit->edit)->hscrollbar);
+    hadjustment = gtk_scrollbar_get_adjustment(composite_edit->hscrollbar);
 
-    g_signal_connect_after(composite_adjustment, "value-changed",
+    g_signal_connect_after(hadjustment, "value-changed",
 			   G_CALLBACK(ags_composite_edit_hscrollbar_callback), composite_edit);
 
+    composite_adjustment = gtk_scrollbar_get_adjustment(AGS_NOTATION_EDIT(composite_edit->edit)->hscrollbar);
+
     g_signal_connect_after(composite_adjustment, "changed",
 			   G_CALLBACK(ags_composite_edit_hscrollbar_changed), composite_edit);
   }
@@ -580,15 +586,18 @@ ags_composite_edit_disconnect(AgsConnectable *connectable)
   }
 
   if(AGS_IS_NOTATION_EDIT(composite_edit->edit)){
+    GtkAdjustment *vadjustment, *hadjustment;
     GtkAdjustment *composite_adjustment;
       
-    composite_adjustment = gtk_scrollbar_get_adjustment(AGS_NOTATION_EDIT(composite_edit->edit)->vscrollbar);
+    vadjustment = gtk_scrollbar_get_adjustment(composite_edit->vscrollbar);
 
-    g_object_disconnect(composite_adjustment,
+    g_object_disconnect(vadjustment,
 			"any_signal::value-changed",
 			G_CALLBACK(ags_composite_edit_vscrollbar_callback),
 			composite_edit,
 			NULL);
+
+    composite_adjustment = gtk_scrollbar_get_adjustment(AGS_NOTATION_EDIT(composite_edit->edit)->vscrollbar);
     
     g_object_disconnect(composite_adjustment,
 			"any_signal::changed",
@@ -596,6 +605,14 @@ ags_composite_edit_disconnect(AgsConnectable *connectable)
 			composite_edit,
 			NULL);
 
+    hadjustment = gtk_scrollbar_get_adjustment(composite_edit->hscrollbar);
+
+    g_object_disconnect(hadjustment,
+			"any_signal::value-changed",
+			G_CALLBACK(ags_composite_edit_hscrollbar_callback),
+			composite_edit,
+			NULL);
+
     composite_adjustment = gtk_scrollbar_get_adjustment(AGS_NOTATION_EDIT(composite_edit->edit)->hscrollbar);
 
     g_object_disconnect(composite_adjustment,
@@ -603,12 +620,6 @@ ags_composite_edit_disconnect(AgsConnectable *connectable)
 			G_CALLBACK(ags_composite_edit_hscrollbar_changed),
 			composite_edit,
 			NULL);
-
-    g_object_disconnect(composite_adjustment,
-			"any_signal::value-changed",
-			G_CALLBACK(ags_composite_edit_hscrollbar_callback),
-			composite_edit,
-			NULL);
   }
 
   if(AGS_IS_SHEET_EDIT(composite_edit->edit)){
