@@ -2404,11 +2404,11 @@ ags_jack_devout_tic(AgsSoundcard *soundcard)
   
   if((16 * (note_offset + 1) >= next_note_256th_offset_lower &&
       16 * (note_offset + 1) <= next_note_256th_offset_upper) ||
-     (next_note_256th_offset_lower + 256 < note_256th_offset_lower)){
+     (next_note_256th_offset_lower + 64 < note_256th_offset_lower)){
     //    g_message("16th pulse: %d (delay = %f)", note_offset + 1, delay);
     
     if(do_loop &&
-       note_offset + 1 == loop_right){
+       next_note_256th_offset_lower + 64 < note_256th_offset_lower){
       ags_soundcard_set_note_offset(soundcard,
 				    loop_left);
 
@@ -2417,29 +2417,8 @@ ags_jack_devout_tic(AgsSoundcard *soundcard)
       jack_devout->note_256th_offset = next_note_256th_offset_lower;
       jack_devout->note_256th_offset_last = next_note_256th_offset_upper;
       
-      note_256th_attack_of_16th_pulse = attack;
-
-      i = 1;
-      
-      if(note_256th_delay < 1.0){
-	for(; i < (guint) ceil(1.0 / note_256th_delay); i++){
-	  if(note_256th_attack_of_16th_pulse_position - i >= 0){
-	    current_note_256th_attack = ags_soundcard_get_note_256th_attack_at_position(soundcard,
-											note_256th_attack_of_16th_pulse_position - i);
-
-	    if(current_note_256th_attack < note_256th_attack_of_16th_pulse){
-	      note_256th_attack_of_16th_pulse = current_note_256th_attack;
-	    }else{
-	      break;
-	    }
-	  }else{
-	    break;
-	  }
-	}
-      }
-
-      jack_devout->note_256th_attack_of_16th_pulse = note_256th_attack_of_16th_pulse;      
-      jack_devout->note_256th_attack_of_16th_pulse_position += i;
+      jack_devout->note_256th_attack_of_16th_pulse = 0;
+      jack_devout->note_256th_attack_of_16th_pulse_position = 0;
 
       g_rec_mutex_unlock(jack_devout_mutex);
     }else{
@@ -2452,27 +2431,20 @@ ags_jack_devout_tic(AgsSoundcard *soundcard)
       jack_devout->note_256th_offset_last = next_note_256th_offset_upper;
 
       note_256th_attack_of_16th_pulse = attack;
+      
+      current_note_256th_attack = attack;
 
       i = 1;
-      
-      if(note_256th_delay < 1.0){
-	for(; i < (guint) ceil(1.0 / note_256th_delay); i++){
-	  if(note_256th_attack_of_16th_pulse_position - i >= 0){
-	    current_note_256th_attack = ags_soundcard_get_note_256th_attack_at_position(soundcard,
-											note_256th_attack_of_16th_pulse_position - i);
 
-	    if(current_note_256th_attack < note_256th_attack_of_16th_pulse){
-	      note_256th_attack_of_16th_pulse = current_note_256th_attack;
-	    }else{
-	      break;
-	    }
-	  }else{
-	    break;
-	  }
-	}
+      current_note_256th_attack = ags_soundcard_get_note_256th_attack_at_position(soundcard,
+										  note_256th_attack_of_16th_pulse_position + 1);
+      
+      for(; attack + (guint) floor((double) i * (note_256th_delay * (double) buffer_size)) < (guint) floor(absolute_delay * (double) buffer_size); i++){
+	current_note_256th_attack = ags_soundcard_get_note_256th_attack_at_position(soundcard,
+										    note_256th_attack_of_16th_pulse_position + i);
       }
 
-      jack_devout->note_256th_attack_of_16th_pulse = note_256th_attack_of_16th_pulse;
+      jack_devout->note_256th_attack_of_16th_pulse = current_note_256th_attack;
       jack_devout->note_256th_attack_of_16th_pulse_position += i;
 
       g_rec_mutex_unlock(jack_devout_mutex);
@@ -2485,7 +2457,7 @@ ags_jack_devout_tic(AgsSoundcard *soundcard)
     g_rec_mutex_lock(jack_devout_mutex);
 
     if(do_loop &&
-       note_offset + 1 == loop_right){
+       next_note_256th_offset_lower + 64 < note_256th_offset_lower){
       jack_devout->tic_counter = 0;
 
       jack_devout->delay_counter = 0.0;
@@ -2507,8 +2479,14 @@ ags_jack_devout_tic(AgsSoundcard *soundcard)
     g_rec_mutex_unlock(jack_devout_mutex);
 
     /* 16th pulse */
-    ags_soundcard_offset_changed(soundcard,
-				 note_offset + 1);
+    if(do_loop &&
+       next_note_256th_offset_lower + 64 < note_256th_offset_lower){
+      ags_soundcard_offset_changed(soundcard,
+				   loop_left);
+    }else{
+      ags_soundcard_offset_changed(soundcard,
+				   note_offset + 1);
+    }
   }else{
     g_rec_mutex_lock(jack_devout_mutex);
     
